/*  Sesame - Storage and Querying architecture for RDF and RDF Schema
 *  Copyright (C) 2001-2006 Aduna
 *
 *  Contact: 
 *  	Aduna
 *  	Prinses Julianaplein 14 b
 *  	3817 CS Amersfoort
 *  	The Netherlands
 *  	tel. +33 (0)33 465 99 87
 *  	fax. +33 (0)33 465 99 87
 *
 *  	http://aduna-software.com/
 *  	http://www.openrdf.org/
 *  
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.openrdf.util.xml;

import java.util.Map;

import org.xml.sax.SAXException;

/**
 * A listener for events reported by <tt>SimpleSAXParser</tt>.
 **/
public interface SimpleSAXListener {

	/**
	 * Notifies the listener that the parser has started parsing.
	 **/
	public void startDocument()
		throws SAXException;

	/**
	 * Notifies the listener that the parser has finished parsing.
	 **/
	public void endDocument()
		throws SAXException;

	/**
	 * Reports a start tag to the listener. The method call reports
	 * the tag's name, the attributes that were found in the start tag
	 * and any text that was found after the start tag.
	 *
	 * @param tagName The tag name.
	 * @param atts A map containing key-value-pairs representing the
	 * attributes that were found in the start tag.
	 * @param text The text immediately following the start tag, or an
	 * empty string if the start tag was followed by a nested start
	 * tag or if no text (other than whitespace) was found between
	 * start- and end tag.
	 **/
	public void startTag(String tagName, Map atts, String text)
		throws SAXException;

	/**
	 * Reports an end tag to the listener.
	 *
	 * @param tagName The tag name.
	 **/
	public void endTag(String tagName)
		throws SAXException;
}
